import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import memoize from 'proxy-memoize';

import { AUTH_REDUCER_NAME, AuthOption, AuthRootState, ModifyAuthOption } from './types';

const initialState: AuthOption = {
	authenticated: undefined,
	accessToken: undefined,
	refreshToken: undefined,
};

const authSlice = createSlice({
	name: AUTH_REDUCER_NAME,
	initialState,
	reducers: {
		setAuthAttribute: (state, action: PayloadAction<AuthOption>) => {
			return {
				...state,
				...action.payload,
			};
		},
		updateAuthAttribute: (state, action: PayloadAction<ModifyAuthOption>) => {
			return {
				...state,
				[action.payload.key]: action.payload.value,
			};
		},
	},
});

export const setAuthAttribute = authSlice.actions.setAuthAttribute as <T>(
	attr: AuthOption<T>
) => PayloadAction<AuthOption<T>>;
export const updateAuthAttribute = authSlice.actions.updateAuthAttribute as <T>(
	attrs: ModifyAuthOption<T>
) => PayloadAction<ModifyAuthOption<T>>;

export const getAuthAttribute = memoize<[AuthRootState, keyof AuthOption], any>(
	([state, attributeName]) => {
		return state.prokyon.auth[attributeName];
	}
) as <T>([state, attributeName]: [AuthRootState, keyof AuthOption<T>]) => any;

export default authSlice.reducer;
