import React, { FC, ReactNode, useCallback } from 'react';
import clsx from 'clsx';

export type DayViewProps = {
	borderSpace?: boolean;
	children?: ReactNode;
	date: Date;
	dayInWeek: number;
	hover?: boolean;
	isSelected: boolean;
	isToday: boolean;
	onClick?: (date: Date) => void;
	weekInMonth: number;
};

export const DayView: FC<DayViewProps> = (props) => {
	const { hover, isToday, isSelected, onClick, children, date, borderSpace } = props;

	const handleClick = useCallback(() => {
		if (onClick && date) {
			onClick(date);
		}
	}, [date, onClick]);

	return (
		<div
			className={clsx(
				{
					'border-0': borderSpace,
					'border-2': !borderSpace,
				},
				'table-cell border-gray-100'
			)}
		>
			<div
				className={clsx('text-center align-top m-0.5 rounded-sm', {
					'hover:bg-focus cursor-pointer': hover && !!date,
					'border border-whitespace': !!date && borderSpace,
					'border-primary-dark border-1': isToday,
					'bg-active': isSelected,
				})}
				onClick={handleClick}
			>
				{children}
			</div>
		</div>
	);
};
