import React, { MouseEvent, useEffect } from 'react';

import CrossIcon from '@prokyon/components/Icons/Cross';
import { isNilOrEmpty } from '@prokyon/utils';

import { ModalId } from '../context';
import { useModal } from '../hooks';

export const Modals = () => {
	const { modals, opened, closeModal } = useModal();

	const handleCloseModal = (modalId: ModalId) => {
		modals[modalId]?.props?.onClose?.();
		closeModal(modalId);
	};

	const handleKeyUp = (e: KeyboardEvent): void => {
		if (e.key === 'Escape') {
			const modalId = opened.at(-1);
			if (modalId !== undefined) {
				handleCloseModal(modalId);
			}
		}
	};

	useEffect(() => {
		window.addEventListener('keydown', handleKeyUp);
		return () => {
			window.removeEventListener('keydown', handleKeyUp);
		};
	}, [handleKeyUp]);

	if (isNilOrEmpty(opened)) {
		return null;
	}

	return (
		<>
			{opened.map((modalId) => {
				const { id, style, title, Component, props } = modals[modalId];
				return (
					<div key={id} className="modal-wrapper">
						<div
							className="modal-container"
							style={{
								width: style?.width,
								...(style?.overrideMaxWidth ? { maxWidth: 'initial' } : {}),
							}}
						>
							<div className="modal-title">
								{title}
								<div className="modal-cross" onClick={() => handleCloseModal(id)}>
									<CrossIcon />
								</div>
							</div>
							<div
								className="modal-body"
								onClick={(e: MouseEvent) => e.stopPropagation()}
							>
								<Component {...props} />
							</div>
						</div>
					</div>
				);
			})}
		</>
	);
};

export default Modals;
