import { useContext, useEffect } from 'react';

import { ModalContext, ModalId } from './context';

type ModalProxyFnInput = {
	close: (modalId: ModalId) => void;
	open: (modalId: ModalId) => void;
};

export let MODAL_PROXY: ModalId[] | null = null;

const opened: ModalId[] = [];
const openedProxyFn = ({ open, close }: ModalProxyFnInput) => {
	return new Proxy(opened, {
		get(target: any, property) {
			if (property === 'splice') {
				return (...args: any) => {
					close(target[args[0]]);
					return target[property](...args);
				};
			}
			return target[property];
		},
		set(target, key, value) {
			if (key !== 'length') {
				open(value);
			}
			Reflect.set(target, key, value);
			return true;
		},
	});
};

export const useModal = () => {
	const { registered, close, open, opened, register, unregister } =
		useContext(ModalContext);

	useEffect(() => {
		MODAL_PROXY = openedProxyFn({ open, close });
	}, []);

	return {
		modals: registered,
		opened: opened,
		openModal: open,
		closeModal: close,
		registerModal: register,
		unregisterModal: unregister,
	};
};
