import React, { useCallback } from 'react';
import clsx from 'clsx';

import { Option } from '@prokyon/types/options';

import { InnerOptionsProps, OptionViewProps } from '../components/RadioButton';

export const CustomOptions: React.FC<OptionViewProps> = (props) => {
	const {
		option: { code, name, disabled },
		onClick,
		value,
		icons,
	} = props as OptionViewProps & InnerOptionsProps;

	const render = useCallback(
		(code: Option['code'], name: Option['name']) => {
			return (
				<div
					onClick={(e) => (!disabled ? onClick({ code, name, disabled }, e) : null)}
					className={clsx('field-radiobutton', {
						'field-radiobutton--active': value === code,
						'field-radiobutton--disabled': disabled,
					})}
				>
					{icons?.[code]}
					<div className="ml-2">{name}</div>
				</div>
			);
		},
		[value, icons]
	);

	return render(code, name);
};
