import React, { MouseEvent, useEffect, useMemo, useRef } from 'react';
import clsx from 'clsx';

import ChevronDownIcon from '@prokyon/components/Icons/ChevronDown';
import ChevronUpIcon from '@prokyon/components/Icons/ChevronUp';
import ExternalIcon from '@prokyon/components/Icons/External';

import { MenuItem } from '../types';

type IProps = {
	className?: string;
	collapsed?: boolean;
	id?: string | null;
	isChild: boolean;
	item: MenuItem;
	onClick: (item: MenuItem) => void;
	setOpen?: (id: string | null) => void;
};

export const Item = (props: IProps) => {
	const {
		onClick,
		isChild,
		item,
		item: { subMenu, icon, external },
		className,
		collapsed,
		id: openID,
		setOpen,
	} = props;

	const id = `${item.label}_${item.href}`;
	const isOpen = openID === id;

	const divRef = useRef<any>();

	const handleOutsideClick = (e: any) => {
		if (!divRef.current.contains(e.target)) {
			setOpen?.(null);
		}
	};

	useEffect(() => {
		document.addEventListener('click', handleOutsideClick);
		return () => document.removeEventListener('click', handleOutsideClick);
	}, []);

	const handleOpen = (e: MouseEvent) => {
		if (isOpen) {
			setOpen?.(null);
		} else {
			setOpen?.(id);
		}
		e.stopPropagation();
	};

	const handleOnClick = () => {
		setOpen?.(null);
		onClick(item);
	};

	const subItems = useMemo(() => {
		if (isOpen && subMenu) {
			return subMenu.map((item, i) => (
				<Item
					key={item.href ?? i}
					isChild={true}
					item={item}
					onClick={onClick}
					id={openID}
					setOpen={setOpen}
					collapsed={collapsed}
				/>
			));
		} else {
			return null;
		}
	}, [isOpen, subMenu, openID, onClick, collapsed]);

	return (
		<div ref={divRef} className={clsx('menu-container', className)}>
			<div
				className={clsx('menu-item', {
					'menu-item--active': isOpen,
					'submenu-item': isChild,
				})}
				onClick={handleOnClick}
			>
				<div className="menu-item-left">
					{icon && <div className="text-xl menu-item-icon">{icon}</div>}
					<div
						className={clsx({
							'menu-item-tooltip': collapsed,
						})}
					>
						{item.label}
					</div>
					{external && (
						<div className="ml-2">
							<ExternalIcon />
						</div>
					)}
				</div>
				{subMenu ? (
					<div className="menu-item-right menu-item-openIcon" onClick={handleOpen}>
						{isOpen ? <ChevronUpIcon /> : <ChevronDownIcon />}
					</div>
				) : (
					<div className="menu-item-right" />
				)}
			</div>
			{subItems && <div className="submenu-container">{subItems}</div>}
		</div>
	);
};

export default MenuItem;
