import React, { createContext, FC, ReactNode, useMemo, useState } from 'react';
import { omit } from 'ramda';

import { StatusEnum } from '@prokyon/types/common';

export type ToasterId = string;

export type Toaster = {
	id: ToasterId;
	message: string;
	status: StatusEnum;
	timeout?: number;
	title?: string;
};

type ToasterContextType = {
	hide: (toasterId: ToasterId) => void;
	show: (toaster: Toaster) => void;
	toasters: Record<ToasterId, Toaster>;
};

export const ToasterContext = createContext<ToasterContextType>({
	toasters: {},
	show: () => {},
	hide: () => {},
});

export const ToasterWrapper: FC<{ children: ReactNode }> = ({ children }) => {
	const [toasters, setToasters] = useState<Record<ToasterId, Toaster>>({});

	const show = (toaster: Toaster) => {
		setToasters({ ...toasters, [toaster.id]: toaster });
	};

	const hide = (toasterId: ToasterId) => {
		setToasters(omit([toasterId], toasters));
	};

	const value = useMemo(
		() => ({
			toasters,
			show,
			hide,
		}),
		[toasters]
	);

	return <ToasterContext.Provider value={value}>{children}</ToasterContext.Provider>;
};

export default ToasterWrapper;
