import { useContext, useEffect } from 'react';

import { Toaster, ToasterContext, ToasterId } from './context';

const TOASTER_TIMEOUT = 4000;

const timeouts: { [key: ToasterId]: any } = [];

type ToasterProxyFnInput = {
	show: (toaster: Toaster) => void;
};

export let TOASTER_PROXY: Toaster[] | null = null;

const opened: Toaster[] = [];
const openedProxyFn = ({ show }: ToasterProxyFnInput) => {
	return new Proxy(opened, {
		set(target, key, value) {
			if (key !== 'length') {
				show(value);
			}
			Reflect.set(target, key, value);
			return true;
		},
	});
};

export const useToaster = () => {
	const { show, hide, toasters } = useContext(ToasterContext);

	const autoHide = (toaster: Toaster) => {
		const { id } = toaster;
		show(toaster);
		timeouts[id] = setTimeout(() => {
			hide(id);
		}, toaster.timeout || TOASTER_TIMEOUT);
	};

	useEffect(() => {
		TOASTER_PROXY = openedProxyFn({ show });
	}, []);

	useEffect(
		() => () => {
			Object.keys(timeouts).forEach((timeoutId) => {
				clearTimeout(timeouts[timeoutId]);
			});
		},
		[]
	);

	return {
		toasters,
		showToaster: autoHide,
		hideToaster: hide,
	};
};
