import React, { FC, useEffect } from 'react';
import { omit } from 'ramda';
import { useController, useFormContext } from 'react-hook-form';

import { DatePicker, DatePickerProps } from '@prokyon/components/DatePicker';
import { StatusEnum } from '@prokyon/types/common';
import { isNilOrEmpty } from '@prokyon/utils';

export type DatePickerFieldProps = DatePickerProps<string>;

export const DatePickerField: FC<DatePickerFieldProps> = (props) => {
	const { name, value, ...others } = props;

	const { control } = useFormContext();
	const {
		field,
		fieldState: { error },
	} = useController({ name, control });

	useEffect(() => {
		if (!isNilOrEmpty(value)) {
			field.onChange(value);
		}
	}, [value]);

	return (
		<>
			<DatePicker
				{...omit(['onClick', 'onFocus'], others)}
				name={field.name}
				value={field.value}
				onChange={field.onChange}
				onBlur={field.onBlur}
				{...(error ? { status: StatusEnum.error } : {})}
			/>
			<div className="field-validationMessage">{error?.message}</div>
		</>
	);
};
