const buildState = ({ color, backgroundColor, borderColor }) => {
	return {
		color: color,
		backgroundColor: backgroundColor,
		borderColor: borderColor,
		boxShadow: `0 4px ${borderColor}`,
		'&:hover:not(:disabled)': {
			boxShadow: `0 2px ${borderColor}`,
			transform: 'translateY(2px)',
		},
		'&:active:not(:disabled)': {
			boxShadow: `0 0 ${borderColor}`,
			transform: 'translateY(4px)',
		},
	};
};

const button = (theme) => ({
	'.button': {
		padding: `${theme('spacing.2')} ${theme('spacing.4')}`,
		margin: `${theme('spacing.2')} auto`,

		display: 'flex',
		justifyContent: 'center',

		width: '100%',
		height: '40px',

		fontSize: '14px',

		borderRadius: theme('borderRadius.md'),
		border: '1px solid',

		textTransform: 'uppercase',
		fontWeight: theme('fontWeight.bold'),

		'&--none': buildState({
			theme,
			color: theme('colors.black.DEFAULT'),
			backgroundColor: theme('colors.whitesmoke'),
			borderColor: theme('colors.gray.300'),
		}),
		'&--info': buildState({
			theme,
			color: theme('colors.black.DEFAULT'),
			backgroundColor: theme('colors.info.DEFAULT'),
			borderColor: theme('colors.info.dark'),
		}),
		'&--success': buildState({
			theme,
			color: theme('colors.black.DEFAULT'),
			backgroundColor: theme('colors.success.DEFAULT'),
			borderColor: theme('colors.success.dark'),
		}),
		'&--warning': buildState({
			theme,
			color: theme('colors.black.DEFAULT'),
			backgroundColor: theme('colors.warning.DEFAULT'),
			borderColor: theme('colors.warning.dark'),
		}),
		'&--error': buildState({
			theme,
			color: theme('colors.white'),
			backgroundColor: theme('colors.error.DEFAULT'),
			borderColor: theme('colors.error.dark'),
		}),
		'&:disabled': {
			color: 'white',
			backgroundColor: theme('colors.whitesmoke'),
			borderColor: theme('colors.gray.50'),
			boxShadow: `0 4px ${theme('colors.gray.50')}`,

			cursor: 'not-allowed',

			transform: 'none',
		},

		'&--pressed': {
			boxShadow: 'none',
			transform: 'translateY(4px)',
		},
	},
});

module.exports = ({ addComponents, theme }) => {
	addComponents(button(theme));
};

module.exports.button = button;
