const buildState = ({ border }) => ({
	'& .field-label': {
		borderColor: border,
		backgroundColor: border,
	},
	'& .field-input': {
		borderColor: border,
		'&--multiline': {
			borderLeftColor: border,
		},
	},
});

const field = (theme) => ({
	'.form-field-container': {
		marginBottom: '.5rem',
	},
	'.field': {
		'&-container': {
			display: 'flex',
			alignItems: 'center',
			fontSize: '15px',
			'&--error': buildState({
				border: theme('colors.error.DEFAULT'),
			}),
			'&--info': buildState({
				border: theme('colors.info.DEFAULT'),
			}),
			'&--warning': buildState({
				border: theme('colors.warning.DEFAULT'),
			}),
			'&--success': buildState({
				border: theme('colors.success.DEFAULT'),
			}),
			'&--multiline': {
				display: 'block',
			},
		},
		'&-label': {
			padding: '0.25rem 1rem 0.25rem 0.5rem',
			color: theme('colors.field.1'),
			backgroundColor: theme('colors.field.DEFAULT'),
			borderRadius: `${theme('borderRadius.md')} 0 0 ${theme('borderRadius.md')}`,
			border: `1px solid ${theme('colors.field.700')}`,
			whiteSpace: 'nowrap',
			height: '2.5rem',
			display: 'flex',
			alignItems: 'center',
			'& > svg': {
				fontSize: '1.4rem',
			},
			'&--multiline': {
				borderRadius: `${theme('borderRadius.md')} ${theme('borderRadius.md')} 0 0`,
			},
		},
		'&-input': {
			padding: '0.25rem',
			outline: 'none',
			height: '2.5rem',
			width: '100%',
			fontWeight: 300,
			boxSizing: 'border-box',
			borderRadius: `0 ${theme('borderRadius.md')} ${theme('borderRadius.md')} 0`,
			border: '1px solid',
			borderLeft: 'none',
			paddingLeft: '.5rem',
			cursor: 'text',
			'&': {
				borderColor: theme('colors.field.700'),
			},
			'&:disabled': {
				backgroundColor: 'transparent',
				border: `1px solid ${theme('colors.whitesmoke')}`,
				borderLeft: 'none',
			},
			'&:read-only': {
				cursor: 'auto',
			},
			'&--nolabel': {
				borderLeft: '1px solid',
				borderColor: theme('colors.field.700'),
				borderRadius: theme('borderRadius.md'),
				'&:disabled': {
					border: `1px solid ${theme('colors.whitesmoke')}`,
				},
			},
			'&--multiline': {
				borderLeftWidth: '1px',
				borderLeftStyle: 'solid',
				borderTop: 'none',
				borderRadius: `0 0 ${theme('borderRadius.md')} ${theme('borderRadius.md')}`,
			},
		},
	},
	'.checkbox-container, .radiobutton-container, .humanverify-container': {
		'.field-label': {
			borderRadius: theme('borderRadius.md'),
		},
		'.field-checkbox, .field-radio': {
			cursor: 'pointer',
			'& > svg': {
				color: theme('colors.field.700'),
			},
			'&--error': {
				color: theme('colors.error.DEFAULT'),
			},
			'&--info': {
				color: theme('colors.info.DEFAULT'),
			},
			'&--warning': {
				color: theme('colors.warning.DEFAULT'),
			},
			'&--disabled': {
				color: theme('colors.whitesmoke'),
				cursor: 'not-allowed',
				'& > svg': {
					color: theme('colors.whitesmoke'),
					cursor: 'not-allowed',
				},
			},
		},
		'.field-radiobutton': {
			display: 'flex',
			textAlign: 'center',
			padding: '.5rem',
			alignItems: 'center',
			height: '100%',
			cursor: 'pointer',
			borderRadius: theme('borderRadius.md'),
			border: `1px solid transparent`,
			'&--disabled': {
				color: theme('colors.whitesmoke'),
				cursor: 'not-allowed',
			},
			'&--active': {
				borderColor: theme('colors.field.900'),
				borderStyle: 'dashed',
				backgroundColor: theme('colors.field.300'),
			},
		},
	},
	'.field-validationMessage': {
		color: theme('colors.error.DEFAULT'),
		textAlign: 'left',
		fontSize: '0.75rem',
	},
});

module.exports = ({ addComponents, theme }) => {
	addComponents(field(theme));
};

module.exports.field = field;
