const skeleton = (theme) => ({
	'.menu': {
		'&-container': {
			position: 'relative',
		},
		'&-item': {
			display: 'flex',
			alignItems: 'center',
			justifyContent: 'space-between',
			fontSize: '15px',
			cursor: 'pointer',
			'&-left': {
				display: 'flex',
				alignItems: 'center',
				justifyContent: 'space-between',
				whiteSpace: 'nowrap',
				position: 'relative',
				padding: '0.5rem 0.125rem 0.5rem .75rem',
			},
			'&-right': {
				padding: '0.5rem 0.75rem 0.5rem 0.125rem',
				'&:empty': {
					padding: '0.25rem',
				},
			},
		},
	},
	'.submenu': {
		'&-container': {
			position: 'relative',
		},
	},
	'.app': {
		margin: '.25rem',
	},
	'.page-top': {
		display: 'flex',
		marginBottom: '0.25rem',
		height: '2.5rem',
		'&-toggler': {
			cursor: 'pointer',
			fontSize: '1.75rem',
			color: theme('colors.navigation.top.0'),
			alignSelf: 'end',
			marginRight: '0.5rem',
		},
		'&-logo': {
			height: 'inherit',
			marginRight: '.25rem',
			display: 'flex',
			alignItems: 'center',
			'& > div': {
				height: 'inherit',
			},
		},
		'&-content': {
			display: 'flex',
			width: '100%',
			backgroundColor: theme('colors.navigation.top.DEFAULT'),
			border: `1px solid ${theme('colors.navigation.top.700')}`,
			borderRadius: theme('borderRadius.sm'),
			'.menu-delimiter': {
				marginLeft: 'auto',
			},
			'.menu-item': {
				color: theme('colors.navigation.top.0'),
				'&-icon': {
					marginRight: '0.125rem',
				},
				'&-openIcon': {
					fontSize: '20px',
				},
				'&-user': {
					'.submenu-container': {
						right: 0,
					},
				},
			},
		},
		'.submenu': {
			'&-container': {
				zIndex: 1,
				marginTop: '.25rem',
				width: 'max-content',
				borderRadius: '2px',
				position: 'absolute',
				backgroundColor: theme('colors.navigation.top.400'),
				border: `1px solid ${theme('colors.navigation.top.DEFAULT')}`,
			},
			'&-item': {
				margin: '0',
			},
		},
	},
	'.page-main': {
		minHeight: '90vh',
		'.side': {
			color: theme('colors.navigation.side.0'),
			backgroundColor: theme('colors.navigation.side.DEFAULT'),
			border: `1px solid ${theme('colors.navigation.side.700')}`,
			borderRadius: theme('borderRadius.sm'),
			position: 'relative',
			paddingTop: '2.5rem',
			marginRight: '.5rem',
			display: 'flex',
			flexDirection: 'column',
			flexShrink: 0,
			'&-toggler': {
				position: 'absolute',
				top: '0.5rem',
				right: '0.5rem',
				cursor: 'pointer',
				fontSize: '1rem',
				color: theme('colors.navigation.side.0'),
			},
			'&--collapsed': {
				width: '2.25rem',
				'.menu-item': {
					'&-left': {
						padding: '0.5rem 0 0.5rem 0.125rem',
					},
					'&-right': {
						padding: '0.5rem 0.25rem 0.5rem 0',
						fontSize: '8px',
					},
					'&-openIcon': {
						fontSize: '0.5rem',
					},
					'&-tooltip': {
						color: theme('colors.navigation.side.0'),
					},
				},
			},
			'&--expand': {
				width: '14rem',
				whiteSpace: 'nowrap',
				'.menu-item-icon': {
					marginRight: '0.25rem',
				},
			},
			'.menu-item': {
				whiteSpace: 'nowrap',
				'&-tooltip': {
					position: 'absolute',
					left: '2.5rem',
					padding: '0.25rem 1rem',
					backgroundColor: theme('colors.black.100'),
					borderRadius: theme('borderRadius.sm'),
					display: 'none',
				},
				'&:hover .menu-item-tooltip': {
					display: 'block',
				},
			},
			'.submenu': {
				'&-container': {
					borderRadius: theme('borderRadius.sm'),
					backgroundColor: theme('colors.navigation.side.400'),
					border: `1px solid ${theme('colors.navigation.side.DEFAULT')}`,
				},
			},
		},
		'.content': {
			margin: '0.25rem',
			width: 'calc(100% - .5rem)',
		},
	},
	// mobile
	[`@media (max-width: ${theme('screens.md-m.max')})`]: {
		'.page-top': {
			height: 'auto',
			flexDirection: 'column',
			'&-logo': {
				margin: '0',
				display: 'inline-block',
				height: 'auto',
			},
			'&-content': {
				height: 'auto',
				flexDirection: 'column',
				'.menu-container': {
					width: '100%',
				},
				'.submenu': {
					'&-container': {
						width: '100%',
						position: 'relative',
						borderRadius: theme('borderRadius.sm'),
					},
				},
			},
		},
	},
});

module.exports = ({ addComponents, theme }) => {
	addComponents(skeleton(theme));
};

module.exports.skeleton = skeleton;
