import React from 'react';
import { action } from '@storybook/addon-actions';
import type { StoryObj } from '@storybook/react';

import { Calendar } from '@prokyon/components/Calendar';
import { CalendarViewEnum } from '@prokyon/components/Calendar/components/Calendar';

import { DayInMonth } from './Calendar/DayInMonth';
import { DayInWeek } from './Calendar/DayInWeek';
import { TimeColumn } from './Calendar/TimeColumn';

type Story = StoryObj<typeof Calendar>;

export default {
	component: Calendar,
	parameters: {
		docs: {
			description: {
				component: "`import Calendar from '@prokyon/components/Calendar';`",
			},
		},
	},
	tags: ['autodocs'],
};

export const MiniCalendar: Story = {
	args: {
		title: 'Mini calendar',
		hover: true,
	},
};

export const MonthCalendar: Story = {
	args: {
		title: 'Month calendar',
		View: DayInMonth,
		type: CalendarViewEnum.month,
		hover: true,
	},
};

export const WeekCalendar: Story = {
	args: {
		title: 'Week calendar',
		View: (props) => <DayInWeek {...props} />,
		TimeColumn: TimeColumn,
		timeColumnWidth: '2.75rem',
		type: CalendarViewEnum.week,
		onClick: () => action('on day change'),
		onRangeChange: action('on range change'),
		hover: true,
	},
};
