import React, { FC, useMemo } from 'react';
import { times } from 'ramda';
import clsx from 'clsx';
import { addMinutes, format } from 'date-fns';

import {
	DayView,
	DayViewProps,
} from '@prokyon/components/Calendar/components/DayView';

import HourView from './HourView';

export const DayInWeek: FC<DayViewProps> = (props) => {
	const { date, onClick, hover, ...others } = props;

	const handleClick = (index: number) => {
		if (onClick && date) {
			const dateTime = addMinutes(date.setHours(8, 0, 0, 0), 30 * index);
			onClick(dateTime);
		}
	};

	const agenda = useMemo(() => {
		return times((i) => {
			if (Math.round(Math.random())) {
				return (
					<HourView
						key={i}
						onClick={() => handleClick(i)}
						className={clsx({
							'hover:bg-focus': hover,
						})}
					/>
				);
			} else {
				return (
					<HourView key={i} className="text-left">
						<div className="bg-primary text-white h-full p-1">event</div>
					</HourView>
				);
			}
		}, 16);
	}, [hover]);

	return (
		<DayView
			{...others}
			isSelected={false}
			hover={false}
			date={date}
			onClick={onClick}
		>
			{date ? format(date, 'dd') : null}
			{agenda}
		</DayView>
	);
};
