import React from 'react';
import { Meta, StoryObj } from '@storybook/react';

import BuildingStoreIcon from '@prokyon/components/Icons/BuildingStore';
import UserTieIcon from '@prokyon/components/Icons/UserTie';
import { RadioButton } from '@prokyon/components/RadioButton';
import { CustomOptions } from '@prokyon/components/RadioButton/components/CustomOptions';

type Story = StoryObj<typeof RadioButton>;

const description = `
\`import DatePicker from '@prokyon/components/DatePicker';\`
`;

export default {
	component: RadioButton,
	parameters: {
		docs: {
			description: {
				component: description,
			},
		},
	},
	tags: ['autodocs'],
} as Meta;

export const Default: Story = {
	args: {
		name: 'default',
		label: 'Classic radio button',
		options: [
			{ name: 'item 1', code: 'item1' },
			{ name: 'item 2', code: 'item2' },
		],
	},
};

export const DefaultDisabled: Story = {
	args: {
		name: 'default',
		label: 'Classic radio button',
		options: [
			{ name: 'item 1', code: 'item1', disabled: true },
			{ name: 'item 2', code: 'item2' },
		],
	},
};

export const HorizontalView: Story = {
	args: {
		name: 'horizontal',
		horizontal: true,
		label: 'Horizontal',
		options: [
			{ name: 'item 1', code: 'item1' },
			{ name: 'item 2', code: 'item2' },
		],
	},
};

export const CustomRender: Story = {
	args: {
		name: 'custom',
		horizontal: true,
		label: 'Custom Render',
		options: [
			{ name: 'Právnická osoba', code: 'legal' },
			{ name: 'Fyzická osoba', code: 'natural' },
		],
		view: <CustomOptions icons={{ natural: <UserTieIcon />, legal: <BuildingStoreIcon /> }} />,
	},
};

export const DisabledCustomRender: Story = {
	args: {
		name: 'disabled',
		horizontal: true,
		label: 'Custom Render',
		options: [
			{ name: 'Právnická osoba', code: 'legal', disabled: true },
			{ name: 'Fyzická osoba', code: 'natural' },
		],
		view: <CustomOptions icons={{ natural: <UserTieIcon />, legal: <BuildingStoreIcon /> }} />,
	},
};

export const Responsive: Story = {
	args: {
		name: 'responsive',
		responsive: true,
		label: 'Responsive',
		options: [
			{ name: 'Právnická osoba', code: 'legal', disabled: true },
			{ name: 'Fyzická osoba', code: 'natural' },
		],
		view: <CustomOptions icons={{ natural: <UserTieIcon />, legal: <BuildingStoreIcon /> }} />,
	},
};
