import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { createBrowserHistory } from 'history';

import { CustomRouter } from '@prokyon/components/CustomRouter';
import MinusIcon from '@prokyon/components/Icons/Minus';
import PlusIcon from '@prokyon/components/Icons/Plus';
import UserIcon from '@prokyon/components/Icons/User';
import { ModalWrapper } from '@prokyon/components/Modal/context';
import Skeleton from '@prokyon/components/Skeleton';

import Router from './Skeleton/Router';

const history = createBrowserHistory();

type Story = StoryObj<typeof Skeleton>;

export default {
	component: Skeleton,
	parameters: {
		docs: {
			description: {
				component: "`import Skeleton from '@prokyon/components/Skeleton';`",
			},
		},
	},
	tags: ['autodocs'],
	decorators: [
		(Story) => (
			<CustomRouter history={history}>
				<ModalWrapper>
					<Story history={history}>
						<Router />
					</Story>
				</ModalWrapper>
			</CustomRouter>
		),
	],
} as Meta;

export const Default: Story = {
	args: {
		children: 'Default Skeleton',
		items: {
			top: [
				{ label: 'Menu 1', href: '/r1', icon: <PlusIcon /> },
				{
					label: 'Menu 2',
					href: '/r2',
					subMenu: [
						{ label: 'Menu 2.1', icon: <PlusIcon /> },
						{ label: 'Založit záznam' },
					],
				},
				{
					label: 'Menu 3',
					href: '/r3',
					subMenu: [{ label: 'Menu 3.1' }, { label: 'Duplikovat záznam' }],
				},
				{
					label: 'Menu 4',
					href: '/r4',
					subMenu: [{ label: 'Menu 4.1' }, { label: 'Duplikovat záznam' }],
				},
				{
					label: 'Menu External',
					href: 'https://prokyon.romanjaros.dev',
					external: true,
				},
				{
					label: 'Menu External 2',
					href: 'https://prokyon.romanjaros.cz',
					external: true,
				},
			],
			side: [
				{ label: 'Menu 1', icon: <MinusIcon /> },
				{
					label: 'Menu 2',
					icon: <PlusIcon />,
					subMenu: [
						{ label: 'Menu 2.1', icon: <UserIcon /> },
						{ label: 'Menu 2.2', icon: <UserIcon /> },
					],
				},
			],
			user: [
				{ label: null, icon: <PlusIcon /> },
				{
					label: 'Roman',
					icon: <UserIcon />,
					subMenu: [{ label: 'Nastavení' }, { label: 'Odhlásit' }],
				},
			],
		},
	},
};

export const WithoutSidePanel: Story = {
	args: {
		children: 'Just content',
		items: {
			top: [
				{ label: 'Menu 1', href: '/r1', icon: <PlusIcon /> },
				{
					label: 'Menu 2',
					href: '/r2',
					subMenu: [
						{ label: 'Menu 2.1', icon: <PlusIcon /> },
						{ label: 'Založit záznam' },
					],
				},
				{
					label: 'Menu 3',
					href: '/r3',
					subMenu: [{ label: 'Menu 3.1' }, { label: 'Duplikovat záznam' }],
				},
				{
					label: 'Menu 4',
					href: '/r4',
					subMenu: [{ label: 'Menu 4.1' }, { label: 'Duplikovat záznam' }],
				},
				{
					label: 'Menu External',
					href: 'https://prokyon.romanjaros.dev',
					external: true,
				},
				{
					label: 'Menu External 2',
					href: 'https://prokyon.romanjaros.cz',
					external: true,
				},
			],
			user: [
				{ label: null, icon: <PlusIcon /> },
				{
					label: 'Roman',
					icon: <UserIcon />,
					subMenu: [{ label: 'Nastavení' }, { label: 'Odhlásit' }],
				},
			],
		},
	},
};

export const WithoutTopNavigation: Story = {
	args: {
		children: 'Just content',
		items: {
			side: [
				{ label: 'Menu 1', icon: <MinusIcon /> },
				{
					label: 'Menu 2',
					icon: <PlusIcon />,
					subMenu: [
						{ label: 'Menu 2.1', icon: <UserIcon /> },
						{ label: 'Menu 2.2', icon: <UserIcon /> },
					],
				},
			],
			user: [
				{ label: null, icon: <PlusIcon /> },
				{
					label: 'Roman',
					icon: <UserIcon />,
					subMenu: [{ label: 'Nastavení' }, { label: 'Odhlásit' }],
				},
			],
		},
	},
};

export const WithTopLogo: Story = {
	args: {
		children: 'Just content',
		items: {
			logo: <div>Logo</div>,
			top: [
				{ label: null, icon: <PlusIcon /> },
				{
					label: 'Roman',
					icon: <UserIcon />,
					subMenu: [{ label: 'Nastavení' }, { label: 'Odhlásit' }],
				},
			],
		},
	},
};

export const JustContent: Story = {
	args: {
		children: 'Just content',
		items: {},
	},
};
