import React, { useCallback } from 'react';
import * as Yup from 'yup';

import Button from '@prokyon/components/Button';
import { CheckboxProps } from '@prokyon/components/Checkbox';
import { DatePickerProps } from '@prokyon/components/DatePicker';
import { Grid, GridSizeEnum } from '@prokyon/components/Grid';
import { GridCol } from '@prokyon/components/GridCol';
import BuildingStoreIcon from '@prokyon/components/Icons/BuildingStore';
import { TextFieldProps } from '@prokyon/components/TextField';
import Field from '@prokyon/forms/components/Field';
import { RadioButtonFieldProps } from '@prokyon/forms/components/fields/RadioButtonField';
import { SelectBoxFieldProps } from '@prokyon/forms/components/fields/SelectBoxField';
import { TimePickerFieldProps } from '@prokyon/forms/components/fields/TimePickerField';
import Form from '@prokyon/forms/components/Form';
import { FIELD_TYPE } from '@prokyon/forms/constants';
import { FormSubmit } from '@prokyon/forms/types';
import useForm from '@prokyon/forms/useForm';
import { StatusEnum } from '@prokyon/types/common';

type FormData = {
	checkbox: boolean;
	datePicker: string;
	radiobutton: string;
	selectBox: string;
	text: string;
	timePicker: string;
};

const radioOptions = [
	{ name: 'Field 1', code: 'field1' },
	{ name: 'Field 2', code: 'field2' },
];

const selectBoxOptions = [
	{ name: 'Option 1', code: 'option1' },
	{ name: 'Option 2', code: 'option2' },
];

const { md } = GridSizeEnum;

const ExampleForm = () => {
	const schema: Yup.SchemaOf<FormData> = Yup.object({
		text: Yup.string().required(),
		checkbox: Yup.boolean().defined(),
		radiobutton: Yup.string().required(),
		selectBox: Yup.string().required(),
		datePicker: Yup.string().required().nullable(),
		timePicker: Yup.string().required().nullable(),
	});

	const formMethods = useForm<FormData>({ schema });
	const { formState } = formMethods;

	const onSubmit: FormSubmit<FormData> = useCallback(
		(data) => {
			const { isDirty, dirtyFields } = formState;
			console.info(data, isDirty, dirtyFields);
		},
		[formState.dirtyFields, formState.isDirty]
	);

	return (
		<Form<FormData> onSubmit={onSubmit} methods={formMethods}>
			<Grid cols={{ [md]: 3 }}>
				<GridCol colSpan={{ [md]: 3 }}>
					<Field<TextFieldProps> name="text" label="Input" component={FIELD_TYPE.TEXT_FIELD} />
					<Field<TextFieldProps> name="text" label={<BuildingStoreIcon />} component={FIELD_TYPE.TEXT_FIELD} />
					<Field<CheckboxProps>
						name="checkbox"
						label="Checkbox"
						description="Do you Agree?"
						component={FIELD_TYPE.CHECKBOX}
					/>
					<Field<RadioButtonFieldProps>
						name="radiobutton"
						label="Radio Button"
						horizontal
						options={radioOptions}
						component={FIELD_TYPE.RADIO_BUTTON}
					/>
					<Field<SelectBoxFieldProps>
						name="selectBox"
						label="SelectBox"
						options={selectBoxOptions}
						component={FIELD_TYPE.SELECT_BOX}
					/>
					<Field<DatePickerProps> name="datePicker" label="DatePicker" component={FIELD_TYPE.DATE_PICKER} />
					<Field<TimePickerFieldProps> name="timePicker" label="TimePicker" component={FIELD_TYPE.TIME_PICKER} />
				</GridCol>
				<GridCol start={{ [md]: 2 }} end={{ [md]: 2 }}>
					<Button type="submit" label="Send" status={StatusEnum.success} />
				</GridCol>
			</Grid>
		</Form>
	);
};

export default ExampleForm;
